==> promise-http-1.0.3-sources.jar: cn/yerl/android/promise/http/ProcessUtils.java <==
package cn.yerl.android.promise.http;

import com.loopj.android.http.RequestParams;

import java.io.File;
import java.io.InputStream;
import java.net.URI;
import java.net.URISyntaxException;
import java.nio.charset.Charset;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

import cz.msebera.android.httpclient.Header;
import cz.msebera.android.httpclient.NameValuePair;
import cz.msebera.android.httpclient.client.utils.URIBuilder;
import cz.msebera.android.httpclient.client.utils.URLEncodedUtils;

/**
 * Created by alan on 2016/12/27.
 */

public class ProcessUtils {
    public static URI processURI(String baseUrl, PromiseRequest request){
        try {
            URIBuilder uriBuilder = new URIBuilder(baseUrl);

            URI requestURI = new URI(request.getUrlString());

            if (requestURI.getHost() != null){
                uriBuilder = new URIBuilder(request.getUrlString()).clearParameters();
            }

            if (requestURI.getPath().startsWith("/")){
                uriBuilder.setPath(requestURI.getPath());
            }else {
                uriBuilder.setPath(uriBuilder.getPath() + "/" + requestURI.getPath());
            }

            List<NameValuePair> queryParams = URLEncodedUtils.parse(requestURI.getQuery(), Charset.forName(request.getEncoding()));
            for (NameValuePair pair : queryParams){
                uriBuilder.setParameter(pair.getName(), pair.getValue());
            }

            for (Map.Entry<String, String> param : request.getQueryParams().entrySet()){
                uriBuilder.setParameter(param.getKey(), param.getValue());
            }

            return uriBuilder.build();
        } catch (URISyntaxException e) {
            throw new RuntimeException(e);
        }
    }

    public static Header[] processHeader(Map<String, String> sharedHeaders, Map<String, String> reuquestHeaders, Map<String, String> sharedCookies, Map<String, String> requestCookies){
//        List<Header> headers = new ArrayList<>();

        Map<String, String> cookies = new HashMap<>();
        cookies.putAll(sharedCookies);
        cookies.putAll(requestCookies);

        Map<String, String> headers = new HashMap<>();
        headers.putAll(sharedHeaders);
        headers.putAll(reuquestHeaders);


//        Header header = new BasicHeader()

        return null;
    }

    public static RequestParams processParams(PromiseRequest request){
        RequestParams params = new RequestParams();
        params.setContentEncoding(request.getEncoding());

        try {
            for (Map.Entry<String, Object> param : request.getBodyParams().entrySet()){
                if (param.getValue() instanceof File){
                    params.put(param.getKey(), (File)param.getValue());
                }else if (param.getValue() instanceof File[]){
                    params.put(param.getKey(), (File[])param.getValue());
                }else if (param.getValue() instanceof InputStream){
                    params.put(param.getKey(), (InputStream)param.getValue());
                }else {
                    params.put(param.getKey(), param.getValue());
                }
            }
        }catch (Exception ex){
            throw new RuntimeException(ex);
        }
        return params;
    }
}

==> promise-http-1.0.7-sources.jar: cn/yerl/android/promise/http/ProcessUtils.java <==
package cn.yerl.android.promise.http;

import com.loopj.android.http.RequestParams;

import java.io.File;
import java.io.InputStream;
import java.net.URI;
import java.net.URISyntaxException;
import java.net.URL;
import java.nio.charset.Charset;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

import cz.msebera.android.httpclient.Header;
import cz.msebera.android.httpclient.NameValuePair;
import cz.msebera.android.httpclient.client.utils.URIBuilder;
import cz.msebera.android.httpclient.client.utils.URLEncodedUtils;
import cz.msebera.android.httpclient.message.BasicHeader;

/**
 * 请求处理工具
 * Created by Alan Yeh on 2016/12/27.
 */
class ProcessUtils {
    /**
     * 处理baseUrl和request的UrlString关系
     */
    public static URI processURI(String baseUrl, PromiseRequest request){
        try {
            URIBuilder uriBuilder = new URIBuilder(baseUrl);

            String URLString = processPathParams(request.getUrlString(), request.getPathParams());

            URI requestURI = new URI(URLString);

            if (requestURI.getHost() != null){
                uriBuilder = new URIBuilder(request.getUrlString()).clearParameters();
            }

            if (requestURI.getPath().startsWith("/")){
                uriBuilder.setPath(requestURI.getPath());
            }else {
                uriBuilder.setPath(uriBuilder.getPath() + "/" + requestURI.getPath());
            }

            List<NameValuePair> queryParams = URLEncodedUtils.parse(requestURI.getQuery(), Charset.forName(request.getEncoding()));
            for (NameValuePair pair : queryParams){
                uriBuilder.setParameter(pair.getName(), pair.getValue());
            }

            for (Map.Entry<String, String> param : request.getQueryParams().entrySet()){
                uriBuilder.setParameter(param.getKey(), param.getValue());
            }

            return uriBuilder.build();
        } catch (URISyntaxException e) {
            throw new RuntimeException(e);
        }
    }

    private static String processPathParams(String URLString, Map<String, Object> pathParams){
        if (URLString.indexOf('{') == -1){
            return URLString;
        }

        for (Map.Entry<String, Object> entry : pathParams.entrySet()){
            URLString = URLString.replaceAll("{" + entry.getKey() + "}", entry.getValue().toString());
        }
        return URLString;
    }

    /**
     * 将shareHeader和requestHeader处理成Header[]
     */
    public static Header[] processHeader(Map<String, String> sharedHeaders, Map<String, String> requestHeaders){
        List<Header> result = new ArrayList<>();

        Map<String, String> headers = new HashMap<>();
        headers.putAll(sharedHeaders);
        headers.putAll(requestHeaders);

        for (Map.Entry<String, String> header : headers.entrySet()){
            result.add(new BasicHeader(header.getKey(), header.getValue()));
        }

        return result.toArray(new Header[result.size()]);
    }

    /**
     * 处理Body参数
     */
    public static RequestParams processParams(PromiseRequest request){
        RequestParams params = new RequestParams();
        params.setContentEncoding(request.getEncoding());

        try {
            for (Map.Entry<String, Object> param : request.getBodyParams().entrySet()){
                if (param.getValue() instanceof File){
                    params.put(param.getKey(), (File)param.getValue());
                }else if (param.getValue() instanceof File[]){
                    params.put(param.getKey(), (File[])param.getValue());
                }else if (param.getValue() instanceof InputStream){
                    params.put(param.getKey(), (InputStream)param.getValue());
                }else {
                    params.put(param.getKey(), param.getValue());
                }
            }
        }catch (Exception ex){
            throw new RuntimeException(ex);
        }
        return params;
    }
}
